import * as AWS from 'aws-sdk';
export interface IServiceCatalogClient {
    searchProducts(input: AWS.ServiceCatalog.ListPortfoliosInput): Promise<AWS.ServiceCatalog.ListPortfoliosOutput>;
    describeProvisioningParameters(input: AWS.ServiceCatalog.DescribeProvisioningParametersInput): Promise<AWS.ServiceCatalog.DescribeProvisioningParametersOutput>;
    describeProduct(input: AWS.ServiceCatalog.DescribeProductInput): Promise<AWS.ServiceCatalog.DescribeProductOutput>;
}
export declare class ServiceCatalogClient implements IServiceCatalogClient {
    private readonly sc;
    constructor();
    searchProducts(input: AWS.ServiceCatalog.SearchProductsInput): Promise<AWS.ServiceCatalog.SearchProductsOutput>;
    describeProvisioningParameters(input: AWS.ServiceCatalog.DescribeProvisioningParametersInput): Promise<AWS.ServiceCatalog.DescribeProvisioningParametersOutput>;
    describeProduct(input: AWS.ServiceCatalog.DescribeProductInput): Promise<AWS.ServiceCatalog.DescribeProductOutput>;
}
/**
 * Provide query values for a specific provisionable product.
 * If no specific IDs are declared for a product, we will use the set `DEFAULT` value for the provisioning artifact and launch path.
 */
export interface DescribeProductAggregateOptions {
    /**
     * A client that performs calls to AWS Service Catalog. You can provide a mock here
     * for testing.
     *
     * @default - A real Service Catalog client
     */
    readonly client?: IServiceCatalogClient;
    /**
     * The product Id.
     */
    readonly productId?: string;
    /**
     * The provisioning artifact Id.
     */
    readonly provisioningArtifactId?: string;
    /**
     * The launch path Id.
     */
    readonly launchPathId?: string;
}
/**
 * Fetches all the available service catalog product(s) for the caller.
 *
 * @returns list of product view summaries
 */
export declare function fetchAvailableProducts(client?: IServiceCatalogClient): Promise<AWS.ServiceCatalog.ProductViewSummaries>;
/**
 * Gets the information required to provision an artifact.
 * Includes information on inputs and outputs of the product.
 *
 * @returns the provisoning parameters for an artifact
 */
export declare function describeProvisioningParameters(options: DescribeProductAggregateOptions): Promise<AWS.ServiceCatalog.DescribeProvisioningParametersOutput>;
/**
 * Holds all the information needed to generate a product artifact to provision.
 */
export interface ProductDataAggregate {
    /**
     * Core product details.
     */
    readonly product: AWS.ServiceCatalog.ProductViewSummary;
    /**
     * Details on the selected provisioning artifact for the product.
     * Represents the actual template that contains resources.
     */
    readonly provisioningArtifact: AWS.ServiceCatalog.ProvisioningArtifact;
    /**
     * Details on the selected launch path for the product.
     * Represents the permissions/ability for end user to provision the product.
     */
    readonly launchPath: AWS.ServiceCatalog.LaunchPathSummary;
    /**
     * Details on provisioning requirements for the provisioning artifact and launch path.
     * Holds information on the inputs and outputs for the downstream template.
     */
    readonly params: AWS.ServiceCatalog.DescribeProvisioningParametersOutput;
}
/**
 * Makes a series of calls to service catalog to get all information
 * required to provision a service catalog product.
 *
 * @returns ProductVersionData aggregate of provisioning artifact details.
 */
export declare function describeProductAggregate(options: DescribeProductAggregateOptions): Promise<ProductDataAggregate>;
